@@ -1,9 +1,17 @@
 ####################################################################
 #' Personal Colours Palette
 #'
-#' This function plots a list of colours on a specific palette
+#' Fetch customizable palettes for the library's usage. The package has
+#' its own default colour-blind friendly colours but can be customized using
+#' R internal options (i.e. \code{options("lares.palette" = c("#FF8303" = "#000",
+#' "#40A4D8" = "#FFF", ...))}. There are 3 options you can use to customize all
+#' colour palletes: "lares.palette" (vector, will be used in the same order as passed,
+#' and must have a counter colour defined), "lares.colours" (vector, simple colour
+#' names and their HEX codes), and "lares.colours.custom" (data.frame, containing
+#' "values" to use dynamically, "fill" for main colour, and "colour" (not obligatory)
+#' for counter colour).
 #'
-#' @family Auxiliary
+#' @family Themes
 #' @param return Character. Get only what you need. Select any of:
 #' "all" or "list" (list),
 #' "colors" or "colours" (vector),
@@ -32,46 +40,27 @@
 #' df[sample(nrow(df), 5), ]
 #' @export
 lares_pal <- function(return = "list") {
-  simple <- c(
-    orange = "#FF8303",
-    blue = "#40A4D8",
-    purple = "#5D3A9B",
-    red = "#E63946",
-    green = "#A1BD4D",
-    navy = "#03396C",
-    yellow = "#F8D962",
-    grey = "#8D99AE",
-    pink = "#FFCAD4",
-    black = "#000000",
-    white = "#F8F8F8"
-  )
 
+  # Generic colour and counter-colour palette
+  colours_names <- getOption("lares.palette")
+  if (length(unique(names(colours_names))) != length(colours_names)) {
+    stop("Check your lares.palette option. Do not repeat colours.")
+  }
+  if (!"character" %in% class(colours_names)) {
+    stop("Check your lares.palette option. Must be a character vector.")
+  }
+
+  # Specific (simple) colours by names
+  simple <- c(getOption("lares.colours"), getOption("lares.colors"))
+  if (length(unique(names(simple))) != length(simple)) {
+    stop("Check your lares.colours option. Do not repeat colours.")
+  }
+  if (!"character" %in% class(simple)) {
+    stop("Check your lares.colours option. Must be a character vector.")
+  }
+
+  # Personal colours list (add more with lares.colours.custom options)
   colours_list <- data.frame(rbind(
-    c("allianz", "#0038A8", simple[["black"]]),
-    c("equidad", "#52CF44", simple[["black"]]),
-    c("colpatria", "#EE0606", simple[["black"]]),
-    c("del estado", "#F37000", simple[["black"]]),
-    c("suramericana", "#1F6D8C", simple[["black"]]),
-    c("mapfre", "#34000D", simple[["black"]]),
-    c("la previsora", "#6F9A45", simple[["black"]]),
-    c("aig", "#C71585", simple[["black"]]),
-    c("generali", "#B21F1F", simple[["black"]]),
-    c("solidaria", "#E69500", simple[["black"]]),
-    c("liberty", "#4E629A", simple[["black"]]),
-    c("bolivar", "#F0F206", simple[["black"]]),
-    c("cia", "#8ACBE5", simple[["black"]]),
-    c("mundial", "#8ACBE5", simple[["black"]]),
-    c("puntored", "#FFFF00", simple[["grey"]]),
-    c("movilred", "#FF1493", simple[["black"]]),
-    c("moviired", "#FF1493", simple[["black"]]),
-    c("moviaval", "#00A69C", simple[["black"]]),
-    c("web", "#290452", simple[["white"]]),
-    c("somosf1", "#290452", simple[["white"]]),
-    c("f1", "#290452", simple[["white"]]),
-    c("funnel-soat4_desktop", "#290452", simple[["white"]]),
-    c("funnel-ujk2d_desktop", "#8ACBE5", simple[["black"]]),
-    c("funnel-ujk2m_old_mobile", "#7AC4E1", simple[["black"]]),
-    c("red", simple[["black"]], simple[["black"]]),
     c("m", simple[["blue"]], simple[["white"]]),
     c("f", simple[["pink"]], simple[["black"]]),
     c("male", simple[["blue"]], simple[["white"]]),
@@ -88,24 +77,20 @@ lares_pal <- function(return = "list") {
     c("X", simple[["grey"]], simple[["black"]]),
     c("good", "#59B3D2", simple[["white"]]),
     c("bad", "#E5586E", simple[["black"]]),
+    c("positive", "#59B3D2", simple[["black"]]),
+    c("negative", "#E5586E", simple[["black"]]),
     c("bueno", "#59B3D2", simple[["white"]]),
     c("malo", "#E5586E", simple[["black"]]),
     c("spring", simple[["green"]], simple[["white"]]),
     c("summer", simple[["red"]], simple[["white"]]),
     c("fall", simple[["orange"]], simple[["black"]]),
     c("winter", simple[["blue"]], simple[["black"]]),
-    c("meg1", "071D49", simple[["white"]]),
-    c("meg2", "EBB600", simple[["black"]]),
-    c("meg3", "F2F1F0", simple[["black"]]),
-    c("meg4", "9A9A9A", simple[["white"]]),
+    c("meg1", "#071D49", simple[["white"]]),
+    c("meg2", "#EBB600", simple[["black"]]),
+    c("meg3", "#F2F1F0", simple[["black"]]),
+    c("meg4", "#9A9A9A", simple[["white"]]),
     c("r5", "#290452", simple[["white"]]),
-    c("olx", simple[["green"]], simple[["black"]]),
-    c("virtualllantas", simple[["red"]], simple[["black"]]),
-    c("eltiempo", "#E5E5E5", simple[["black"]]),
-    c("autolab", simple[["orange"]], simple[["black"]]),
-    c("aflore", simple[["blue"]], simple[["black"]]),
     c("otro", simple[["grey"]], simple[["black"]]),
-    c("negative", "#FA4113", simple[["black"]]),
     c("fear", "#810806", simple[["white"]]),
     c("disgust", "#BF200E", simple[["black"]]),
     c("anger", "#FE9B13", simple[["black"]]),
@@ -114,48 +99,32 @@ lares_pal <- function(return = "list") {
     c("surprise", "#F7E565", simple[["black"]]),
     c("trust", "#40A4D8", simple[["black"]]),
     c("joy", "#BD116F", simple[["black"]]),
-    c("positive", "#3DA4AB", simple[["black"]]),
     c("fb1", "#405996", simple[["white"]]),
     c("fb2", "#7184B2", simple[["black"]]),
-    c("fb3", "#AFBEE3", simple[["black"]])
+    c("fb3", "#AFBEE3", simple[["black"]]),
+    c("facebook", "#4267B2", simple[["black"]]),
+    c("instagram", "#E95950", simple[["black"]]),
+    c("messenger", "#0084FF", simple[["black"]]),
+    c("whatsapp", "#4DC247", simple[["black"]])
   ))
   colnames(colours_list) <- c("values", "fill", "colour")
 
-  # Generic colour and counter-colour palette
-  colours_names <- c(
-    "#FF8303" = simple[["black"]],
-    "#40A4D8" = simple[["black"]],
-    "#5D3A9B" = simple[["white"]],
-    "#E63946" = simple[["black"]],
-    "#2A9D8F" = simple[["black"]],
-    "#D35FB7" = simple[["black"]],
-    "#F8D962" = simple[["black"]],
-    "#03396C" = simple[["white"]],
-    "#F29595" = simple[["black"]],
-    "#2FFECC" = simple[["black"]],
-    "#8D99AE" = simple[["black"]],
-    "#7ADf90" = simple[["black"]],
-    "#290452" = simple[["white"]],
-    "#0C7BDC" = simple[["black"]],
-    "#817B7B" = simple[["black"]],
-    "#F66320" = simple[["black"]],
-    "#F4A261" = simple[["black"]],
-    "#005AB5" = simple[["white"]],
-    "#9A9A9A" = simple[["black"]],
-    "#00008B" = simple[["white"]],
-    "#E1BE6A" = simple[["black"]],
-    "#40B0A6" = simple[["black"]],
-    "#056E00" = simple[["white"]],
-    "#E40000" = simple[["black"]],
-    "#FE8A71" = simple[["black"]],
-    "#8600A1" = simple[["white"]],
-    "#A52A2A" = simple[["white"]],
-    "#000000" = simple[["white"]],
-    "#E69F00" = simple[["black"]],
-    "#009E73" = simple[["black"]],
-    "#0072B2" = simple[["white"]],
-    "#D55E00" = simple[["black"]]
-  )
+  more_cols <- getOption("lares.colours.custom")
+  if (length(more_cols) > 1) {
+    if (!"data.frame" %in% class(more_cols)) {
+      stop("Check your lares.colours.custom option. Must be a data.frame.")
+    }
+    if (!"colour" %in% colnames(more_cols)) more_cols$colour <- "#000"
+    if (!all(colnames(more_cols) %in% colnames(colours_list))) {
+      stop(
+        "Check your lares.colours.custom option. Column names must match: ",
+        v2t(colnames(colours_list))
+      )
+    }
+    colours_list <- colours_list %>%
+      filter(!.data$values %in% more_cols$values) %>%
+      bind_rows(more_cols)
+  }
 
   pal <- list(
     labels = colours_list,
@@ -187,7 +156,7 @@ lares_pal <- function(return = "list") {
 #'
 #' This function plots a list of colours
 #'
-#' @family Auxiliary
+#' @family Themes
 #' @param fill Vector. List of colours for fills.
 #' @param colour Vector. List of colours for colours.
 #' @param id Vector. ID for each color.
@@ -223,51 +192,3 @@ plot_palette <- function(fill, colour = "black", id = NA, limit = 12) {
     theme_lares(font = NA, axis = "Y")
   return(p)
 }
-
-
-####################################################################
-#' Custom colours for scale_color_manual [Deprecated]
-#'
-#' This function lets the user use pre-defined default colours
-#'
-#' @family Auxiliary
-#' @return Same as \code{scale_color_manual} but with custom palette.
-#' @export
-gg_colour_customs <- function() {
-  colours_list <- lares_pal()$labels
-  values <- as.character(t(colours_list$colour)[1, ])
-  names(values) <- colours_list$values
-  return(scale_color_manual(values = values))
-}
-
-
-####################################################################
-#' Custom colours for scale_fill_manual [Deprecated]
-#'
-#' This function lets the user use pre-defined default colours
-#'
-#' @family Auxiliary
-#' @return Same as \code{scale_fill_manual} but with custom palette.
-#' @export
-gg_fill_customs <- function() {
-  colours_list <- lares_pal()$labels
-  values <- as.character(t(colours_list$fill)[1, ])
-  names(values) <- colours_list$values
-  return(scale_fill_manual(values = values))
-}
-
-
-####################################################################
-#' Custom colours for scale_color_manual on texts [Deprecated]
-#'
-#' This function lets the user use pre-defined default colours
-#'
-#' @family Auxiliary
-#' @return Same as \code{scale_color_manual} but with custom palette.
-#' @export
-gg_text_customs <- function() {
-  colours_list <- lares_pal()$labels
-  values <- as.character(t(colours_list$colour)[1, ])
-  names(values) <- colours_list$values
-  return(scale_color_manual(values = values))
-}
